==> haskell-lifted-base-0.2.3.11-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lifted-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-base
version: 0.2.3.11
id: lifted-base-0.2.3.11-6Z5sbMH60be9gIey8uuzks
key: lifted-base-0.2.3.11-6Z5sbMH60be9gIey8uuzks
license: BSD3
copyright: (c) 2011-2012 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/lifted-base
synopsis: lifted IO operations from the base library
description:
    @lifted-base@ exports IO operations from the base library lifted to
    any instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
    .
    Note that not all modules from @base@ are converted yet. If
    you need a lifted version of a function from @base@, just
    ask me to add it or send me a patch.
    .
    The package includes a copy of the @monad-peel@ testsuite written
    by Anders Kaseorg The tests can be performed using @cabal test@.
category: Control
author: Bas van Dijk, Anders Kaseorg
exposed: True
exposed-modules:
    Control.Exception.Lifted Control.Concurrent.MVar.Lifted
    Control.Concurrent.Chan.Lifted Control.Concurrent.QSem.Lifted
    Control.Concurrent.QSemN.Lifted Control.Concurrent.Lifted
    Data.IORef.Lifted Foreign.Marshal.Utils.Lifted
    System.Timeout.Lifted
abi: 7fcae71c790fd24448b3fc4d0e9ae8d7
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/lifted-base-0.2.3.11
library-dirs: /usr/lib/ghc-8.0.1/site-local/lifted-base-0.2.3.11
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/lifted-base-0.2.3.11
hs-libraries: HSlifted-base-0.2.3.11-6Z5sbMH60be9gIey8uuzks
includes:
    inlinable.h
depends:
    base-4.9.0.0 monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-lifted-base/html/lifted-base.haddock
haddock-html: /usr/share/doc/haskell-lifted-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lifted-base-0.2.3.11-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lifted-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lifted-base
version: 0.2.3.11
id: lifted-base-0.2.3.11-D5Xv69EKf6L9rLXYpe3sxE
key: lifted-base-0.2.3.11-D5Xv69EKf6L9rLXYpe3sxE
license: BSD3
copyright: (c) 2011-2012 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/lifted-base
synopsis: lifted IO operations from the base library
description:
    @lifted-base@ exports IO operations from the base library lifted to
    any instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.
    .
    Note that not all modules from @base@ are converted yet. If
    you need a lifted version of a function from @base@, just
    ask me to add it or send me a patch.
    .
    The package includes a copy of the @monad-peel@ testsuite written
    by Anders Kaseorg The tests can be performed using @cabal test@.
category: Control
author: Bas van Dijk, Anders Kaseorg
exposed: True
exposed-modules:
    Control.Exception.Lifted Control.Concurrent.MVar.Lifted
    Control.Concurrent.Chan.Lifted Control.Concurrent.QSem.Lifted
    Control.Concurrent.QSemN.Lifted Control.Concurrent.Lifted
    Data.IORef.Lifted Foreign.Marshal.Utils.Lifted
    System.Timeout.Lifted
abi: 37314ca7feb78598275f1f31e75d12c1
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/lifted-base-0.2.3.11
library-dirs: /usr/lib/ghc-8.0.1/site-local/lifted-base-0.2.3.11
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/lifted-base-0.2.3.11
hs-libraries: HSlifted-base-0.2.3.11-D5Xv69EKf6L9rLXYpe3sxE
includes:
    inlinable.h
depends:
    base-4.9.0.0 monad-control-1.0.2.0-4qPEnRApnc4gRDkIzJcM5
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-lifted-base/html/lifted-base.haddock
haddock-html: /usr/share/doc/haskell-lifted-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
